/**
 * 数据库连接测试API
 * 作者: 阿瑞
 * 功能: 测试系统数据库连接是否正常
 * 版本: 1.0
 */

import { NextRequest, NextResponse } from 'next/server';
import { connectSystemDB, RequestWithDB } from '@/lib/db';

/**
 * 测试数据库连接的处理器
 */
async function handler(req: RequestWithDB) {
  try {
    // 尝试执行一个简单的查询
    const [result] = await req.db.query('SELECT 1 as connected');
    
    return NextResponse.json({
      success: true,
      message: '数据库连接成功',
      data: result
    });
  } catch (error) {
    console.error('数据库连接测试失败:', error);
    
    return NextResponse.json({
      success: false,
      error: error instanceof Error ? error.message : '未知错误'
    }, { status: 500 });
  }
}

// 使用数据库连接中间件包装处理器
/**
 * 处理GET请求
 * 符合Next.js 15.3+的路由处理器签名
 */
export async function GET(request: NextRequest) {
  const wrappedHandler = connectSystemDB(handler);
  return wrappedHandler(request);
} 